@@ -15,6 +15,7 @@ from .entities import (
     AzureStorageTier,
     BucketsConfig,
     CloudProvider,
+    CloudProviderType,
     Cluster,
     ClusterLocationType,
     ClusterStatus,
@@ -38,12 +39,14 @@ from .entities import (
     NeuroAuthConfig,
     NodePool,
     NodeRole,
+    NotificationType,
     OnPremCloudProvider,
     OpenStackCredentials,
     OrchestratorConfig,
     RegistryConfig,
     ResourcePoolType,
     ResourcePreset,
+    Resources,
     SecretsConfig,
     SentryCredentials,
     StorageConfig,
@@ -70,6 +73,7 @@ __all__ = [
     "AzureStorageTier",
     "BucketsConfig",
     "CloudProvider",
+    "CloudProviderType",
     "Cluster",
     "ClusterLocationType",
     "ClusterStatus",
@@ -93,12 +97,14 @@ __all__ = [
     "NeuroAuthConfig",
     "NodePool",
     "NodeRole",
+    "NotificationType",
     "OnPremCloudProvider",
     "OpenStackCredentials",
     "OrchestratorConfig",
     "RegistryConfig",
     "ResourcePoolType",
     "ResourcePreset",
+    "Resources",
     "SecretsConfig",
     "SentryCredentials",
     "StorageConfig",
