@@ -129,11 +129,6 @@ class ClusterLocationType(str, enum.Enum):
     REGIONAL = "regional"
 
 
-class GoogleStorageBackend(str, enum.Enum):
-    FILESTORE = "filestore"  # Google Cloud Filestore
-    GCS_NFS = "gcs-nfs"  # Google Cloud Storage
-
-
 class GoogleFilestoreTier(str, enum.Enum):
     STANDARD = "STANDARD"
     PREMIUM = "PREMIUM"
@@ -436,6 +431,8 @@ class IdleJobConfig:
     count: int
     image: str
     resources: Resources
+    command: list[str] = field(default_factory=list)
+    args: list[str] = field(default_factory=list)
     image_pull_secret: str | None = None
     env: dict[str, str] = field(default_factory=dict)
     node_selector: dict[str, str] = field(default_factory=dict)
@@ -452,6 +449,7 @@ class OrchestratorConfig:
     resource_pool_types: Sequence[ResourcePoolType] = ()
     resource_presets: Sequence[ResourcePreset] = ()
     allow_privileged_mode: bool = False
+    allow_job_priority: bool = False
     pre_pull_images: Sequence[str] = ()
     idle_jobs: Sequence[IdleJobConfig] = ()
 
