@@ -95,7 +95,6 @@ class TestEntityFactory:
                     "job_schedule_scale_up_timeout_s": 2,
                     "is_http_ingress_secure": False,
                     "resource_pool_types": [{"name": "node-pool"}],
-                    "allow_privileged_mode": False,
                 },
                 "storage": {"url": "https://storage-dev.neu.ro"},
                 "registry": {
@@ -155,7 +154,8 @@ class TestEntityFactory:
                         "memory_mb": 100,
                     }
                 ],
-                "allow_privileged_mode": False,
+                "allow_privileged_mode": True,
+                "allow_job_priority": True,
                 "pre_pull_images": ["neuromation/base"],
                 "idle_jobs": [
                     {
@@ -163,7 +163,18 @@ class TestEntityFactory:
                         "count": 1,
                         "image": "miner",
                         "resources": {"cpu_m": 1000, "memory_mb": 1024},
-                    }
+                    },
+                    {
+                        "name": "idle",
+                        "count": 1,
+                        "image": "miner",
+                        "command": ["bash"],
+                        "args": ["-c", "sleep infinity"],
+                        "resources": {"cpu_m": 1000, "memory_mb": 1024},
+                        "env": {"NAME": "VALUE"},
+                        "node_selector": {"label": "value"},
+                        "image_pull_secret": "secret",
+                    },
                 ],
             }
         )
@@ -177,7 +188,8 @@ class TestEntityFactory:
             is_http_ingress_secure=False,
             resource_pool_types=[mock.ANY],
             resource_presets=[mock.ANY],
-            allow_privileged_mode=False,
+            allow_privileged_mode=True,
+            allow_job_priority=True,
             pre_pull_images=["neuromation/base"],
             idle_jobs=[
                 IdleJobConfig(
@@ -185,7 +197,18 @@ class TestEntityFactory:
                     count=1,
                     image="miner",
                     resources=Resources(cpu_m=1000, memory_mb=1024),
-                )
+                ),
+                IdleJobConfig(
+                    name="idle",
+                    count=1,
+                    image="miner",
+                    command=["bash"],
+                    args=["-c", "sleep infinity"],
+                    resources=Resources(cpu_m=1000, memory_mb=1024),
+                    env={"NAME": "VALUE"},
+                    node_selector={"label": "value"},
+                    image_pull_secret="secret",
+                ),
             ],
         )
 
@@ -197,7 +220,6 @@ class TestEntityFactory:
                 "job_schedule_timeout_s": 1,
                 "job_schedule_scale_up_timeout_s": 2,
                 "is_http_ingress_secure": False,
-                "allow_privileged_mode": False,
             }
         )
 
@@ -208,7 +230,6 @@ class TestEntityFactory:
             job_schedule_timeout_s=1,
             job_schedule_scale_up_timeout_s=2,
             is_http_ingress_secure=False,
-            allow_privileged_mode=False,
             resource_pool_types=[],
             resource_presets=[],
             idle_jobs=[],
@@ -1146,6 +1167,8 @@ class TestPayloadFactory:
                 job_schedule_timeout_s=1,
                 job_schedule_scale_up_timeout_s=2,
                 is_http_ingress_secure=False,
+                allow_privileged_mode=True,
+                allow_job_priority=True,
                 resource_pool_types=[ResourcePoolType(name="cpu")],
                 resource_presets=[
                     ResourcePreset(
@@ -1155,7 +1178,6 @@ class TestPayloadFactory:
                         memory_mb=100,
                     )
                 ],
-                allow_privileged_mode=False,
                 pre_pull_images=["neuromation/base"],
                 idle_jobs=[
                     IdleJobConfig(
@@ -1163,7 +1185,18 @@ class TestPayloadFactory:
                         count=1,
                         image="miner",
                         resources=Resources(cpu_m=1000, memory_mb=1024),
-                    )
+                    ),
+                    IdleJobConfig(
+                        name="idle",
+                        count=1,
+                        image="miner",
+                        command=["bash"],
+                        args=["-c", "sleep infinity"],
+                        resources=Resources(cpu_m=1000, memory_mb=1024),
+                        env={"NAME": "VALUE"},
+                        node_selector={"label": "value"},
+                        image_pull_secret="secret",
+                    ),
                 ],
             )
         )
@@ -1177,7 +1210,8 @@ class TestPayloadFactory:
             "is_http_ingress_secure": False,
             "resource_pool_types": [mock.ANY],
             "resource_presets": [mock.ANY],
-            "allow_privileged_mode": False,
+            "allow_privileged_mode": True,
+            "allow_job_priority": True,
             "pre_pull_images": ["neuromation/base"],
             "idle_jobs": [
                 {
@@ -1185,7 +1219,18 @@ class TestPayloadFactory:
                     "count": 1,
                     "image": "miner",
                     "resources": {"cpu_m": 1000, "memory_mb": 1024},
-                }
+                },
+                {
+                    "name": "idle",
+                    "count": 1,
+                    "image": "miner",
+                    "command": ["bash"],
+                    "args": ["-c", "sleep infinity"],
+                    "resources": {"cpu_m": 1000, "memory_mb": 1024},
+                    "env": {"NAME": "VALUE"},
+                    "node_selector": {"label": "value"},
+                    "image_pull_secret": "secret",
+                },
             ],
         }
 
@@ -1198,7 +1243,6 @@ class TestPayloadFactory:
                 job_schedule_timeout_s=1,
                 job_schedule_scale_up_timeout_s=2,
                 is_http_ingress_secure=False,
-                allow_privileged_mode=False,
             )
         )
 
@@ -1208,7 +1252,6 @@ class TestPayloadFactory:
             "job_schedule_timeout_s": 1,
             "job_schedule_scale_up_timeout_s": 2,
             "is_http_ingress_secure": False,
-            "allow_privileged_mode": False,
         }
 
     def test_create_resource_pool_type(self, factory: PayloadFactory) -> None:
